@@ -33,6 +33,7 @@ struct _CEPageVpn
 {
         GtkBox parent;
 
+        GtkBox     *box;
         GtkLabel   *failure_label;
         GtkEntry   *name_entry;
 
@@ -109,8 +110,8 @@ load_vpn_plugin (CEPageVpn *self)
 	}
         vpn_gnome3ify_editor (ui_widget);
 
-        gtk_box_remove (GTK_BOX (self), GTK_WIDGET (self->failure_label));
-        gtk_box_append (GTK_BOX (self), ui_widget);
+        gtk_box_remove (self->box, GTK_WIDGET (self->failure_label));
+        gtk_box_append (self->box, ui_widget);
 
         g_signal_connect_object (self->editor, "changed", G_CALLBACK (ce_page_changed), self, G_CONNECT_SWAPPED);
 }
@@ -184,6 +185,7 @@ ce_page_vpn_class_init (CEPageVpnClass *class)
 
         gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/control-center/network/vpn-page.ui");
 
+        gtk_widget_class_bind_template_child (widget_class, CEPageVpn, box);
         gtk_widget_class_bind_template_child (widget_class, CEPageVpn, failure_label);
         gtk_widget_class_bind_template_child (widget_class, CEPageVpn, name_entry);
 }
